=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2007-12-18 22:17:35 +0000
+++ bzrlib/branch.py	2007-12-20 14:28:59 +0000
@@ -764,6 +764,10 @@
         :param revision_id: The revision to check out
         :param lightweight: If True, produce a lightweight checkout, otherwise,
         produce a bound branch (heavyweight checkout)
+        :param accelerator_tree: A tree which can be used for retrieving file
+            contents more quickly than the revision tree, i.e. a workingtree.
+            The revision tree will be used for cases where accelerator_tree's
+            content is different.
         :return: The tree of the created checkout
         """
         t = transport.get_transport(to_location)

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2007-12-19 15:00:22 +0000
+++ bzrlib/bzrdir.py	2007-12-20 14:28:59 +0000
@@ -381,11 +381,16 @@
                                                format=format).bzrdir
         return bzrdir.create_workingtree()
 
-    def create_workingtree(self, revision_id=None, from_branch=None):
+    def create_workingtree(self, revision_id=None, from_branch=None,
+        accelerator_tree=None):
         """Create a working tree at this BzrDir.
         
         :param revision_id: create it as of this revision id.
         :param from_branch: override bzrdir branch (for lightweight checkouts)
+        :param accelerator_tree: A tree which can be used for retrieving file
+            contents more quickly than the revision tree, i.e. a workingtree.
+            The revision tree will be used for cases where accelerator_tree's
+            content is different.
         """
         raise NotImplementedError(self.create_workingtree)
 
@@ -824,6 +829,10 @@
 
         if revision_id is not None, then the clone operation may tune
             itself to download less data.
+        :param accelerator_tree: A tree which can be used for retrieving file
+            contents more quickly than the revision tree, i.e. a workingtree.
+            The revision tree will be used for cases where accelerator_tree's
+            content is different.
         """
         target_transport = get_transport(url, possible_transports)
         target_transport.ensure_base()

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2007-12-19 18:01:46 +0000
+++ bzrlib/transform.py	2007-12-20 14:28:59 +0000
@@ -1335,6 +1335,12 @@
     - Otherwise, if the content on disk matches the content we are building,
       it is silently replaced.
     - Otherwise, conflict resolution will move the old file to 'oldname.moved'.
+
+    :param tree: The tree to convert wt into a copy of
+    :param wt: The working tree that files will be placed into
+    :param accelerator_tree: A tree which can be used for retrieving file
+        contents more quickly than tree itself, i.e. a workingtree.  tree
+        will be used for cases where accelerator_tree's content is different.
     """
     wt.lock_tree_write()
     try:

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2007-12-18 23:12:06 +0000
+++ bzrlib/workingtree.py	2007-12-20 14:28:59 +0000
@@ -2832,8 +2832,12 @@
                    accelerator_tree=None):
         """See WorkingTreeFormat.initialize().
         
-        revision_id allows creating a working tree at a different
-        revision than the branch is at.
+        :param revision_id: if supplied, create a working tree at a different
+            revision than the branch is at.
+        :param accelerator_tree: A tree which can be used for retrieving file
+            contents more quickly than the revision tree, i.e. a workingtree.
+            The revision tree will be used for cases where accelerator_tree's
+            content is different.
         """
         if not isinstance(a_bzrdir.transport, LocalTransport):
             raise errors.NotLocalUrl(a_bzrdir.transport.base)

=== modified file 'bzrlib/workingtree_4.py'
--- bzrlib/workingtree_4.py	2007-12-19 18:02:44 +0000
+++ bzrlib/workingtree_4.py	2007-12-20 14:28:59 +0000
@@ -1262,6 +1262,10 @@
 
         :param revision_id: allows creating a working tree at a different
         revision than the branch is at.
+        :param accelerator_tree: A tree which can be used for retrieving file
+            contents more quickly than the revision tree, i.e. a workingtree.
+            The revision tree will be used for cases where accelerator_tree's
+            content is different.
 
         These trees get an initial random root id, if their repository supports
         rich root data, TREE_ROOT otherwise.

